﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Kinect;

namespace MultiKinect
{
    /// <summary>
    /// Interaction logic for MappingPanel.xaml
    /// </summary>
    public partial class MappingPanel : UserControl
    {
        private float x;
        private float y;
        private float z;
        private SkeletonPoint offset;

        public MappingPanel()
        {
            InitializeComponent();
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            this.x = 0.0f;
            this.y = 0.0f;
            this.z = 0.0f;

            offset = new SkeletonPoint();

            xLabel.Content = x.ToString();
            yLabel.Content = y.ToString();
            zLabel.Content = z.ToString();

            xText.TextChanged += new TextChangedEventHandler(xText_TextChanged);
            yText.TextChanged += new TextChangedEventHandler(yText_TextChanged);
            zText.TextChanged += new TextChangedEventHandler(zText_TextChanged);
        }

        void zText_TextChanged(object sender, TextChangedEventArgs e)
        {
            TextBox tb = e.Source as TextBox;
            this.z = ConvertToFloat(tb.Text);
            zLabel.Content = z.ToString();
            textHasChanged();
        }

        void yText_TextChanged(object sender, TextChangedEventArgs e)
        {
            TextBox tb = e.Source as TextBox;
            this.y = ConvertToFloat(tb.Text);
            yLabel.Content = y.ToString();
            textHasChanged();
        }

        void xText_TextChanged(object sender, TextChangedEventArgs e)
        {
            TextBox tb = e.Source as TextBox;
            this.x = ConvertToFloat(tb.Text);
            xLabel.Content = x.ToString();
            textHasChanged();
        }

        private float ConvertToFloat(string input)
        {
            float f = 0.0f;
            try
            {
                f = float.Parse(input);
            }
            catch (Exception)
            { 
                
            }
            return f;
        }

        private void textHasChanged()
        {
            offset.X = x;
            offset.Y = y;
            offset.Z = z;
        }

        public SkeletonPoint Offset
        {
            get { return this.offset; }
        }

        public float X
        {
            get { return this.x; }
        }

        public float Y
        {
            get { return this.y; }
        }

        public float Z
        {
            get { return this.z; }
        }

        public void CamActive(bool input)
        {
            if (input)
            {
                ellipse1.Fill = new SolidColorBrush(Colors.Green);
            }
            else
            {
                ellipse1.Fill = new SolidColorBrush(Colors.Red);
            }
        }

        public void TrackingActive(bool input)
        {
            if (input)
            {
                ellipse2.Fill = new SolidColorBrush(Colors.Green);
            }
            else
            {
                ellipse2.Fill = new SolidColorBrush(Colors.Red);
            }
        }

        public void TrackingMainCam(bool input)
        {
            if (input)
            {
                ellipse3.Fill = new SolidColorBrush(Colors.Green);
            }
            else
            {
                ellipse3.Fill = new SolidColorBrush(Colors.Red);
            }
        }
    }
}
