﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Media.Media3D;
using Microsoft.Kinect;

namespace MultiKinect
{
    static class MultiKinectHelpers
    {
        private static TranslateTransform3D _translate3d = new TranslateTransform3D();
        
        public static void setTransform(SkeletonPoint point)
        {
            Vector3D trans = new Vector3D(point.X, point.Y, point.Z);
            _translate3d = new TranslateTransform3D(trans);
        }

        public static SkeletonPoint normalizeKinectPoint(SkeletonPoint point)
        {
            Point3D tpoint = new Point3D(point.X, point.Y, point.Z);
            tpoint = _translate3d.Transform(tpoint);
            point.X = (float)tpoint.X;
            point.Y = (float)tpoint.Y;
            point.Z = (float)tpoint.Z;
            return point;
        }

        public static double JointDistance(Joint p1, Joint p2)
        {
            return Math.Sqrt(
                Math.Pow(p1.Position.X - p2.Position.X, 2) +
                Math.Pow(p1.Position.Y - p2.Position.Y, 2) +
                Math.Pow(p1.Position.Z - p2.Position.Z, 2));        
        }

        public static double JointsLength(params Joint[] joints)
        {
            double length = 0;

            for (int index = 0; index < joints.Length - 1; index++)
            {
                length += JointDistance(joints[index], joints[index + 1]);
            }

            return length;
        }

        public static int NumberOfTrackedJoints(params Joint[] joints)
        {
            int trackedJoints = 0;

            foreach (var joint in joints)
            {
                if (joint.TrackingState == JointTrackingState.Tracked)
                {
                    trackedJoints++;
                }
            }

            return trackedJoints;
        }

        public static double Height(this Skeleton skeleton)
        {
            const double HEAD_DIVERGENCE = 0.1;

            var head = skeleton.Joints[JointType.Head];
            var neck = skeleton.Joints[JointType.ShoulderCenter];
            var spine = skeleton.Joints[JointType.Spine];
            var waist = skeleton.Joints[JointType.HipCenter];
            var hipLeft = skeleton.Joints[JointType.HipLeft];
            var hipRight = skeleton.Joints[JointType.HipRight];
            var kneeLeft = skeleton.Joints[JointType.KneeLeft];
            var kneeRight = skeleton.Joints[JointType.KneeRight];
            var ankleLeft = skeleton.Joints[JointType.AnkleLeft];
            var ankleRight = skeleton.Joints[JointType.AnkleRight];
            var footLeft = skeleton.Joints[JointType.FootLeft];
            var footRight = skeleton.Joints[JointType.FootRight];

            // Find which leg is tracked more accurately.
            int legLeftTrackedJoints = NumberOfTrackedJoints(hipLeft, kneeLeft, ankleLeft, footLeft);
            int legRightTrackedJoints = NumberOfTrackedJoints(hipRight, kneeRight, ankleRight, footRight);

            double legLength = legLeftTrackedJoints > legRightTrackedJoints ? JointsLength(hipLeft, kneeLeft, ankleLeft, footLeft) : JointsLength(hipRight, kneeRight, ankleRight, footRight);

            return JointsLength(head, neck, spine, waist) + legLength + HEAD_DIVERGENCE;
        } 
    }
}
