﻿using System;
using System.Net;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Bespoke.Common;
using Bespoke.Common.Osc;
using Microsoft.Kinect;

namespace MultiKinect
{
    /// <summary>
    /// Handles OSC TCP connection and shows Feedback for the connection
    /// </summary>
    public partial class OscFeedback : UserControl
    {
        private IPAddress targetAddress;
        private int targetPort;
        private TcpTransmitter oscSender;
        private bool isStarted = false;
        private static readonly string AliveMethod = "/multikinect/alive";
        private static readonly string GlobalMethod = "/multikinect/globalposition";
        private static readonly string JointMethod = "/multikinect/joints";
        public OscFeedback()
        {
            InitializeComponent();
        }

        public void startOsc()
        {
            oscSender.Start(targetAddress, targetPort);
            if (oscSender.isConnected())
            {
                textBox1.Text = "Connected!";
                isStarted = true;
            }
            else
            {
                textBox1.Text = "Failed to Connect!";
                isStarted = false;
            }
        }

        public bool IsStarted()
        {
            return isStarted;
        }


        public void stopOsc()
        {
            oscSender.Stop();
            isStarted = false;
        }

        public void AddressChanged()
        {
            if (oscSender.isConnected())
            {
                stopOsc();
                startOsc();
            }
        }

        public bool setIpAddress(string address)
        {
            IPAddress tempAddress;
            if (IPAddress.TryParse(address, out tempAddress))
            {
                targetAddress = tempAddress;
                return true;
            }
            return false;
        }

        public bool setPort(string input)
        {
            int temp = 0;
            if (int.TryParse(input, out temp))
            {
                targetPort = temp;
                return true;
            }
            return false;
        }

        public bool sendMessage(MultiKinect.MultiSkeleton skeleton)
        {
            OscBundle bundle = new OscBundle(oscSender.getDestination());
            OscMessage message = new OscMessage(oscSender.getDestination(), AliveMethod);
            OscMessage globalPosition = new OscMessage(oscSender.getDestination(), GlobalMethod);
            OscMessage jointPosition = new OscMessage(oscSender.getDestination(), JointMethod);
            message.Append(skeleton.Name);
            globalPosition.Append(skeleton.GlobalPosition.X);
            globalPosition.Append(skeleton.GlobalPosition.Y);
            globalPosition.Append(skeleton.GlobalPosition.Z);

            foreach (Joint joint in skeleton.Skeleton.Joints)
            {
                if (joint.TrackingState != JointTrackingState.NotTracked)
                {
                    jointPosition.Append(joint.JointType.ToString());
                    jointPosition.Append(joint.Position.X);
                    jointPosition.Append(joint.Position.Y);
                    jointPosition.Append(joint.Position.Z);
                }
            }

            bundle.Append(message);
            bundle.Append(globalPosition);
            bundle.Append(jointPosition);
            bool sended = oscSender.SendPacket(bundle);
            return sended;
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            oscSender = new TcpTransmitter();
            targetAddress = IPAddress.Loopback;
            targetPort = 5103;
            textBox1.Text = "Not Connected!";
        }
    }
}
