﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace MultiKinect
{
    /// <summary>
    /// Interaction logic for UserRadar.xaml
    /// </summary>
    public partial class UserRadar : UserControl
    {
        private Dictionary<int, Ellipse> allPlayers = new Dictionary<int, Ellipse>();
        private Dictionary<int, Label> allIDs = new Dictionary<int, Label>();

        public UserRadar()
        {
            InitializeComponent();
        }


        public void AddPlayer(Point position, int id, string status = "")
        {
            //Add Ellipse
            Ellipse ellipse = new Ellipse { Width = 10.0, Height = 10.0 };
            ellipse.StrokeThickness = 1.0;
            ellipse.Stroke = Brushes.Black;
            if (status == "TU1")
                ellipse.Fill = Brushes.Magenta;
            else if (status == "TU2")
                ellipse.Fill = Brushes.LimeGreen;
            else if (status == "P")
                ellipse.Fill = Brushes.LightGray;
            else
                ellipse.Fill = Brushes.Red;
            canvas1.Children.Add(ellipse);
            Canvas.SetLeft(ellipse, position.X - 5.0);
            Canvas.SetTop(ellipse, position.Y - 5.0);
            allPlayers.Add(id, ellipse);
            //Add Label
            Label label = new Label { Width = 48.0, Height = 20.0, FontSize = 9.0 };
            label.Content = id.ToString() + status;
            canvas1.Children.Add(label);
            Canvas.SetLeft(label, position.X + 5.0);
            Canvas.SetTop(label, position.Y - 10.0);
            allIDs.Add(id, label);
        }

        public void UpdatePosition(Point position, int id, string status = "")
        {
            if(allPlayers.ContainsKey(id))
            {
                Ellipse ellipse; 
                if(allPlayers.TryGetValue(id, out ellipse))
                {
                    if (status == "TU1")
                        ellipse.Fill = Brushes.Magenta;
                    else if (status == "TU2")
                        ellipse.Fill = Brushes.LimeGreen;
                    else if (status == "P")
                        ellipse.Fill = Brushes.LightGray;
                    else
                        ellipse.Fill = Brushes.Red;
                    Canvas.SetLeft(ellipse, position.X - 5.0);
                    Canvas.SetTop(ellipse, position.Y - 5.0);
                }
            }

            if (allIDs.ContainsKey(id))
            {
                Label label;
                if (allIDs.TryGetValue(id, out label))
                {
                    Canvas.SetLeft(label, position.X + 5.0);
                    Canvas.SetTop(label, position.Y - 10.0);
                    label.Content = id.ToString() + status;
                }
            }

        }

        public void RemovePlayer(int id)
        {
            if (allPlayers.ContainsKey(id))
            {
                Ellipse ellips;
                if (allPlayers.TryGetValue(id, out ellips))
                {
                    canvas1.Children.Remove(ellips);
                    allPlayers.Remove(id);
                }
            }

            if (allIDs.ContainsKey(id))
            {
                Label label;
                if (allIDs.TryGetValue(id, out label))
                {
                    canvas1.Children.Remove(label);
                    allIDs.Remove(id);
                }
            }
        }

        public bool PlayerExists(int id)
        {
            return allPlayers.ContainsKey(id);
        }

        public List<int> getIDs()
        {
            return allPlayers.Keys.ToList();
        }

    }
}
